@@ -1,12 +1,13 @@
 package IPC::System::Options;
 
-our $DATE = '2015-01-12'; # DATE
-our $VERSION = '0.03'; # VERSION
+our $DATE = '2015-02-07'; # DATE
+our $VERSION = '0.04'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 
+use Carp;
 use Proc::ChildError qw(explain_child_error);
 
 use Exporter qw(import);
@@ -81,7 +82,7 @@ sub _system_or_backtick {
         $log->tracef("%s(%s) failed: %d (%s)",
                      $which, \@_, $?, explain_child_error())
             if $opts->{log};
-        die "$which(".join(" ", @_).") failed: " . explain_child_error()
+        croak "$which(".join(" ", @_).") failed: " . explain_child_error()
             if $opts->{die};
     }
 
@@ -111,7 +112,7 @@ IPC::System::Options - Perl's system() and backtick/qx replacement/wrapper, with
 
 =head1 VERSION
 
-This document describes version 0.03 of IPC::System::Options (from Perl distribution IPC-System-Options), released on 2015-01-12.
+This document describes version 0.04 of IPC::System::Options (from Perl distribution IPC-System-Options), released on 2015-02-07.
 
 =head1 SYNOPSIS
 
